Форум БГУИР • Главная страница

# Форум БГУИР

Пропустить

Расширенный поиск

Текущее время: Ср дек 10, 2014 1:13 am

- Сообщения без ответов • Активные темы

- Для Абитуриентов
    Темы
    Сообщений
    Последнее сообщение

- Для абитуриентов
  Для тех, кто мечтает стать студентом лучшего ВУЗа Беларуси
    106 Темы
    346 Сообщений
    Последнее сообщение oirso
    Вт дек 09, 2014 12:27 pm

- Для Студентов
    Темы
    Сообщений
    Последнее сообщение

- Барахолка
  Покупка/продажа студенческих "принадлежностей" - книг, конспектов, курсовых... ;)
    218 Темы
    538 Сообщений
    Последнее сообщение Гамлет
    Вс ноя 02, 2014 6:12 am
- Вакансии
  Рабочие вакансии
    218 Темы
    323 Сообщений
    Последнее сообщение Aspir
    Пт ноя 07, 2014 10:45 am
- Общий для студентов
  форум, посвящённый студентам самого лучшего университета страны...
    128 Темы
    726 Сообщений
    Последнее сообщение oldboy2003
    Пт дек 05, 2014 9:02 pm

- Для Сотрудников
    Темы
    Сообщений
    Последнее сообщение

- Общий для сотрудников
  Обсуждение общих вопросов...
    43 Темы
    430 Сообщений
    Последнее сообщение megastatus
    Чт сен 11, 2014 9:09 pm

- Для Посетителей
    Темы
    Сообщений
    Последнее сообщение

- Для посетителей
  Первый раз на сайте? Интересует какая-либо дополнительная информация, касаемая университета или портала? Вам сюда...
    135 Темы
    840 Сообщений
    Последнее сообщение Tess
    Ср авг 27, 2014 9:22 pm

- Флейм
    Темы
    Сообщений
    Последнее сообщение

- Флейм
  Здесь вы можете говорить о чем угодно.
    53 Темы
    113 Сообщений
    Последнее сообщение marunaleksei
    Ср окт 15, 2014 4:30 pm

- Опросы
    Темы
    Сообщений
    Последнее сообщение

- Опросы
  голосование и обсуждение жизни, связанной с лучшим университетом страны
    20 Темы
    275 Сообщений
    Последнее сообщение FedorB
    Пн окт 27, 2014 1:24 pm

- Технический
    Темы
    Сообщений
    Последнее сообщение

- Software
  Поиск и скачивание программ, решение любых вопросов, связанных с ПО
    11 Темы
    38 Сообщений
    Последнее сообщение romper7stomper
    Вс мар 30, 2014 3:38 pm
- Hardware
  Хотите купить видеокарту, но не знаете какую? Нужны новые драйвера? Решение любых вопросов, связанных с железом...
    11 Темы
    76 Сообщений
    Последнее сообщение ремонт компьютеров
    Пн янв 14, 2013 7:24 pm
- Антивирусный центр
  Форум, посвященный вопросам антивирусной безопасности (в частности, сетей БГУИР)...
    7 Темы
    63 Сообщений
    Последнее сообщение Yrevich
    Ср июл 09, 2014 10:33 pm
- Программирование
  Помощь в программировании, написанию лаб, курсовых, программ и т.п.
    58 Темы
    157 Сообщений
    Последнее сообщение Olegon
    Пн окт 06, 2014 4:49 pm

- Досуг и Развлечения
    Темы
    Сообщений
    Последнее сообщение

- Встречи участников форума
    11 Темы
    156 Сообщений
    Последнее сообщение вапывр
    Чт сен 16, 2010 4:28 pm
- Досуг в городе Минске
  Делимся опытом о том, как хорошо провести время в Минске
    16 Темы
    71 Сообщений
    Последнее сообщение Anastassia
    Ср окт 08, 2014 8:00 am
- Музыка
  Обсуждение музыки всех жанров и направлений, любимых групп и исполнителей, поиск музыки.
    20 Темы
    297 Сообщений
    Последнее сообщение matrix13777
    Вт апр 08, 2014 11:41 am
- Фильмы
  Обсуждение любимых фильмов, новинок из мира кинематографа, поиск фильмов
    9 Темы
    204 Сообщений
    Последнее сообщение zeetwang707
    Вс ноя 30, 2014 3:29 pm
- Юмор
  Делимся анекдотами и просто смешными случаями из нашей жизни
    5 Темы
    67 Сообщений
    Последнее сообщение admera
    Вс июл 06, 2014 10:26 am
- Спорт
  Вы любите спорт?
    15 Темы
    49 Сообщений
    Последнее сообщение anyuta_filatova
    Вт июл 22, 2014 7:49 am
- Internet
  Делимся полезными и интересными ссылками в глобальной сети Internet
    18 Темы
    55 Сообщений
    Последнее сообщение Lidia
    Пн фев 24, 2014 12:54 pm
- От любви до ненависти
  Говорим обо всех видах отношений между людьми
    4 Темы
    175 Сообщений
    Последнее сообщение buxus999
    Вс май 18, 2014 6:01 pm
- Чтение
  Обсуждение писателей, книг, средств массовой информации
    5 Темы
    45 Сообщений
    Последнее сообщение Alekslit
    Вс сен 01, 2013 12:58 pm

### Вход • Регистрация

Имя пользователя: Пароль: | Автоматически входить при каждом посещении

### Кто сейчас на форуме

Сейчас посетителей на форуме: 1, из них 1 зарегистрированных искрытых: 0 (основано на активности пользователей за последние 5 минут)
Больше всего посетителей (6) на форуме было Пн окт 27, 2014 1:30 pm
Зарегистрированные пользователи: Yandex [bot]
Легенда: Администраторы, Главные модераторы

### Статистика

Всего сообщений: 9143 • Тем: 1313 • Пользователей: 3690 • Новый пользователь: oldboy2003